@@ -1,13 +1,13 @@
 from scipy.io import loadmat, savemat
-from os import path, system, remove
+from os import path, system
 
 
 class RunOctave:
 
-    __version__ = '1.0.0'
+    __version__ = '1.0.2'
 
     def __init__(self, octave_path):
-        self.octave_path = octave_path
+        self.octave_path = octave_path.replace(' ','" "')
         self.alphabet = 'abcdefghijklmnopqrstuvwxyz'
         self.CSL = ','.join(self.alphabet)  # Comma-separated letters
 
